@@ -1,16 +1,12 @@
 from .__about__ import __version__
-from .create import (
-    create_colormap,
-    find_max_srgb_radius,
-    show_circular,
-    show_kovesi_test_image,
-    show_linear,
-)
-from .main import get_srgb1, plot, save_fig, save_img, show, tripcolor
+from .benchmark import show_kovesi_test_image, show_test_function
+from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
+from .main import get_srgb1, save_fig, save_img, tripcolor
 
 __all__ = [
     "__version__",
     #
+    "show_test_function",
     "show_kovesi_test_image",
     "show_linear",
     "show_circular",
